# White124
**Combining methods for convenience in new projects:**  

from white124 import MySQL  
&nbsp;&nbsp;&nbsp;&nbsp;def connect  
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Query to MySQL database  
&nbsp;&nbsp;&nbsp;&nbsp;def send_bd  
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Request to the server via socket, sterilization if necessary  

from white124 import DomGosuslugi  
&nbsp;&nbsp;&nbsp;&nbsp;def apiFias  
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Uses the Dadata library to generate the correct address in FIAS format 